@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '4.13';
+our $VERSION = '4.14';
 
 use WWW::Curl ();
 use Exporter  ();
@@ -44,6 +44,11 @@ sub AUTOLOAD {
     return $value;
 }
 
+sub pushopt {
+    my ($self, $option, $value) = @_;
+    $self->setopt($option, $value, 1);
+}
+
 1;
 
 __END__
