@@ -3,24 +3,31 @@ package WWW::Curl::Share;
 use strict;
 use warnings;
 use Carp;
-use vars qw(@ISA @EXPORT @EXPORT_OK $AUTOLOAD);
 
-use WWW::Curl;
-require Exporter;
-require AutoLoader;
+use WWW::Curl ();
+use Exporter  ();
 
-@ISA = qw(Exporter DynaLoader);
+our @ISA = qw(Exporter);
 
-@EXPORT = qw(
+our @EXPORT = qw(
 );
 
 sub AUTOLOAD {
-
+    our $AUTOLOAD;
     # This AUTOLOAD is used to 'autoload' constants from the constant()
     # XS function.
 
     ( my $constname = $AUTOLOAD ) =~ s/.*:://;
-    return constant( $constname, 0 );
+    my $value = constant( $constname );
+    if($!) {
+        croak("Undefined subroutine &$AUTOLOAD failed");
+    }
+
+    {
+        no strict 'refs';
+        *{$AUTOLOAD} = sub { $value };
+    }
+    return $value;
 }
 
 1;
